Use the skim function to validate your data and output a summary of your columns
ers_column_info.RdThis function applies skimr::skim() to summarize a dataset and then formats numeric columns.
Numeric values are rounded to one decimal place. If a number is 1,000 or greater, it is formatted with commas.