Output your data as a nicely formatted table using the gt package
Usage
ers_table(dataset, title = "Default Title")
Arguments
- dataset
REQUIRED: The data that you want to make into a table
- title
REQUIRED: Desired title of your data table. Example: "Teacher FTE by School"
Value
Your data as a nicely formatted table