Create a new ERS R Markdown file from a template
Usage
ers_template(file_name, include_walkthrough = FALSE)
Arguments
- file_name
The name of the new Rmd file to create (e.g., "my_report"). You do not need to include the .Rmd extension.
- include_walkthrough
If TRUE or "yes", use the walkthrough template; otherwise, use the standard template
Value
Creates a new Rmd file in your working directory